@@ -70,10 +70,10 @@ import weakref
 from ae.system import DATE_ISO, DATE_TIME_ISO                                       # type: ignore
 
 
-__version__ = '0.1.1'
+__version__ = '0.1.3'
 
 
-# suppress unused import err (needed e.g. for unpickling of dates via try_eval())
+# suppress unused import err (needed e.g. for unpickling of dates via try_eval() and for include them into base_globals)
 _d = (DATE_ISO, DATE_TIME_ISO,
       ascii_letters, digits, datetime, logging, logging_config, threading, unicodedata, weakref)
 
@@ -101,9 +101,9 @@ def exec_with_return(code_block: str, ignored_exceptions: Tuple[Type[Exception],
                                 the ignorable exceptions raised or if last code line is no expression.
     """
     if glo_vars is None:
-        glo_vars = globals()
-    if loc_vars is None:
-        loc_vars = locals()
+        glo_vars = base_globals
+    elif '_add_base_globals' in glo_vars:
+        glo_vars.update(base_globals)
 
     try:
         code_ast = ast.parse(code_block)    # raises SyntaxError if code block is invalid
@@ -244,8 +244,11 @@ def stack_variables(*skip_modules: str, find_name: str = '', max_depth: int = 0,
 
     :param skip_modules:    module names to skip (def=see :data:`SKIPPED_MODULES` module constant).
     :param find_name:       if passed then the returned stack frame must contain a variable with the passed name.
-    :param max_depth:       the maximum depth in the call stack from which to return the variables. if this argument
-                            and :paramref:`~stack_variable.find_name` get not passed then
+    :param max_depth:       the maximum depth in the call stack from which to return the variables.
+                            If the specified argument is not zero and no :paramref:`~stack_variables.skip_modules`
+                            are specified then the first deeper stack frame that is not within the default
+                            :data:`SKIPPED_MODULES` will be returned.
+                            If this argument and :paramref:`~stack_variable.find_name` get not passed then
                             the variables of the top stack frame will be returned.
     :param min_depth:       the calling level from which on to search (def=3 which refers the next deeper stack frame
                             of the caller of this function).
@@ -269,7 +272,8 @@ def stack_variables(*skip_modules: str, find_name: str = '', max_depth: int = 0,
             break
         if max_depth and depth > max_depth:
             break
-    return glo, loc, depth - 1
+    # experienced strange overwrites of locals (e.g. self) when returning f_locals directly (adding .copy() fixed it)
+    return glo.copy(), loc.copy(), depth - 1
 
 
 stack_vars = stack_variables        #: alias of function :func:`.stack_variables`
@@ -305,9 +309,9 @@ def try_eval(expr: str, ignored_exceptions: Tuple[Type[Exception], ...] = (),
     ret = None
 
     if glo_vars is None:
-        glo_vars = globals()
-    if loc_vars is None:
-        loc_vars = locals()
+        glo_vars = base_globals
+    elif '_add_base_globals' in glo_vars:
+        glo_vars.update(base_globals)
 
     try:  # catch type conversion errors, e.g. for datetime.date(None) while bool(None) works (->False)
         ret = eval(expr, glo_vars, loc_vars)
@@ -327,14 +331,11 @@ def try_exec(code_block: str, ignored_exceptions: Tuple[Type[Exception], ...] =
     :return:                    function return value or None if a ignored exception got thrown.
     """
     ret = None
-
-    if glo_vars is None:
-        glo_vars = globals()
-    if loc_vars is None:
-        loc_vars = locals()
-
     try:
         ret = exec_with_return(code_block, glo_vars=glo_vars, loc_vars=loc_vars)
     except ignored_exceptions:
         pass
     return ret
+
+
+base_globals = globals()        #: default if no global variables get passed in dynamic code/expression evaluations
